@@ -27,10 +27,32 @@ class payment(models.Model):
     title = models.CharField(max_length=100, blank=True, default='')
     amount = models.IntegerField()
     phone=models.CharField(max_length=100)
-   
+    CheckoutRequestID=models.CharField(max_length=500,default='')
+    success=models.BooleanField(default=False)
+    payment_status_message=models.CharField(max_length=500,default='')
+
 
     class Meta:
         ordering = ('created',)
-    
+
     def __str__(self):
-        return self.title
\ No newline at end of file
+        return self.title
+
+
+class QueryURLS(models.Model):
+    created = models.DateTimeField(auto_now_add=True)
+    api_url_query = models.CharField(max_length=500, blank=True, default='')
+
+
+
+    class Meta:
+        ordering = ('created',)
+        verbose_name = 'Query URL'
+        verbose_name_plural='Query and Balances urls'
+
+
+
+    def __str__(self):
+        return self.api_url_query
+
+
